@@ -92,8 +92,10 @@ extern ssize_t (*pseudo_real_fgetxattr)(int, const char *, void *, size_t);
 extern int (*pseudo_real_lsetxattr)(const char *, const char *, const void *, size_t, int);
 extern int (*pseudo_real_fsetxattr)(int, const char *, const void *, size_t, int);
 #endif
-extern int (*pseudo_real_lstat)(const char *, struct stat *);
-extern int (*pseudo_real_fstat)(int, struct stat *);
+/* later, the init code can change these to refer to the real calls and
+ * skip the wrappers.
+ */
+extern int (*pseudo_real_lstat)(const char *path, PSEUDO_STATBUF *buf);
 
 static void
 _libpseudo_init(void) {
@@ -175,8 +177,7 @@ pseudo_init_wrappers(void) {
 	pseudo_real_lsetxattr = real_lsetxattr;
 	pseudo_real_fsetxattr = real_fsetxattr;
 #endif
-	pseudo_real_lstat = real_lstat;
-	pseudo_real_fstat = real_fstat;
+	pseudo_real_lstat = base_lstat;
 
 	/* Once the wrappers are setup, we can now use open... so
 	 * setup the logfile, if necessary...
